# PdCheckers

Tool to investigate consistency and dirtiness of a pandas DataFrame

## Installation

```shell
pip install pdcheckers
```

## Usage

Check ```example.ipynb```

## Data

Original mock data from version 0.1 generated https://mockaroo.com/. Dirtiness introduced.